/**
 * Downloads a refill from repository and integrates it into project
 * @param  {Object}   opts     {repository: [String, Object], destination: String}
 * @param  {Function} done End state done
 * @return {null}
 */
module.exports = function(opts, done) {
    'use strict';

    var ghdownload = require('github-download'),
        mkdirp = require('mkdirp').sync,
        exists = require('fs').existsSync,
        fse = require('fs-extra'),
        _ = require('lodash'),
        Case = require('case'),
        path = require('path'),
        pluralize = require('pluralize'),
        remove = fse.removeSync;

    if (!_.has(opts, 'repository')) {
        return done(new Error('Repository not defined in the opts.'));
    }

    if (!_.has(opts, 'name')) {
        return done(new Error('Refill must have a name.'));
    }

    if (exists('./temp_feds/')) {
        remove('./temp_feds');
    }

    mkdirp('./temp_feds');

    var result = null;

    ghdownload(opts.repository, 'temp_feds')
        .on('error', function(err) {
            result = err;
        })
        .on('end', function() {

            try {

                var refill_pkg = fse.readJsonSync('./temp_feds/package.json'),
                    dest = path.join(opts.destination, pluralize(refill_pkg.type.toLowerCase()), opts.subfolder || '', opts.name);

                fse.copy('./temp_feds/src/', dest, function(err) {
                    remove('./fedstemp');
                    if (err) return done(err);
                    done();
                });


            } catch (err) {
                return done(err);
            }
        });
};
